<?php
namespace App\Controllers;

use App\Models\Report;
use App\Helpers\PdfHelper;

class ReportController
{
    /**
     * Muestra la lista de reportes generados
     */
    public function index()
    {
        $reportes = Report::getAll();
        include '../app/Views/reports/list.php';
    }

    /**
     * Muestra el formulario para generar un nuevo reporte
     */
    public function create()
    {
        include '../app/Views/reports/create.php';
    }

    /**
     * Genera un reporte y lo almacena en la base de datos
     */
    public function store()
    {
        $datosReporte = $_POST;

        if (empty($datosReporte['titulo']) || empty($datosReporte['contenido'])) {
            $_SESSION['error'] = "Todos los campos son obligatorios.";
            header("Location: /reports/create");
            exit;
        }

        Report::save($datosReporte);

        $_SESSION['success'] = "Reporte generado exitosamente.";
        header("Location: /reports");
        exit;
    }

    /**
     * Genera un reporte en formato PDF
     */
    public function generatePdf($id)
    {
        $reporte = Report::find($id);
        
        if (!$reporte) {
            $_SESSION['error'] = "Reporte no encontrado.";
            header("Location: /reports");
            exit;
        }
        
        $pdfHelper = new PdfHelper();
        $pdfHelper->generarPdfReporte($reporte);
    }

    /**
     * Elimina un reporte de la base de datos
     */
    public function delete($id)
    {
        if (!Report::find($id)) {
            $_SESSION['error'] = "Reporte no encontrado.";
            header("Location: /reports");
            exit;
        }

        Report::delete($id);
        $_SESSION['success'] = "Reporte eliminado correctamente.";
        header("Location: /reports");
        exit;
    }
}
