<?php
namespace App\Controllers;

use App\Models\User;

class UserController
{
    /**
     * Muestra la lista de usuarios
     */
    public function index()
    {
        $usuarios = User::getAll();
        include '../app/Views/users/list.php';
    }

    /**
     * Muestra el formulario para crear un nuevo usuario
     */
    public function create()
    {
        include '../app/Views/users/create.php';
    }

    /**
     * Guarda un nuevo usuario en la base de datos
     */
    public function store()
    {
        $datosUsuario = $_POST;

        if (empty($datosUsuario['nombre']) || empty($datosUsuario['email']) || empty($datosUsuario['password'])) {
            $_SESSION['error'] = "Todos los campos son obligatorios.";
            header("Location: /users/create");
            exit;
        }

        if (User::findByEmail($datosUsuario['email'])) {
            $_SESSION['error'] = "El correo ya está registrado.";
            header("Location: /users/create");
            exit;
        }

        $datosUsuario['password'] = password_hash($datosUsuario['password'], PASSWORD_BCRYPT);
        User::save($datosUsuario);

        $_SESSION['success'] = "Usuario creado exitosamente.";
        header("Location: /users");
        exit;
    }

    /**
     * Muestra el formulario para editar un usuario
     */
    public function edit($id)
    {
        $usuario = User::find($id);
        if (!$usuario) {
            $_SESSION['error'] = "Usuario no encontrado.";
            header("Location: /users");
            exit;
        }

        include '../app/Views/users/edit.php';
    }

    /**
     * Actualiza los datos de un usuario en la base de datos
     */
    public function update($id)
    {
        $datosUsuario = $_POST;

        if (empty($datosUsuario['nombre']) || empty($datosUsuario['email'])) {
            $_SESSION['error'] = "Nombre y correo son obligatorios.";
            header("Location: /users/edit/$id");
            exit;
        }

        if (!empty($datosUsuario['password'])) {
            $datosUsuario['password'] = password_hash($datosUsuario['password'], PASSWORD_BCRYPT);
        } else {
            unset($datosUsuario['password']);
        }

        User::update($id, $datosUsuario);

        $_SESSION['success'] = "Usuario actualizado correctamente.";
        header("Location: /users");
        exit;
    }

    /**
     * Elimina un usuario de la base de datos
     */
    public function delete($id)
    {
        if (!User::find($id)) {
            $_SESSION['error'] = "Usuario no encontrado.";
            header("Location: /users");
            exit;
        }

        User::delete($id);
        $_SESSION['success'] = "Usuario eliminado correctamente.";
        header("Location: /users");
        exit;
    }
}
