<?php
namespace App\Models;

use PDO;
use App\Database\Connection;

class User
{
    /**
     * Obtiene todos los usuarios
     */
    public static function getAll()
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->query("SELECT * FROM users");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Busca un usuario por su email
     */
    public static function findByEmail($email)
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->prepare("SELECT * FROM users WHERE email = ?");
        $stmt->execute([$email]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    /**
     * Guarda un nuevo usuario en la base de datos
     */
    public static function save($data)
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->prepare("INSERT INTO users (nombre, email, password) VALUES (?, ?, ?)");
        return $stmt->execute([$data['nombre'], $data['email'], $data['password']]);
    }

    /**
     * Encuentra un usuario por ID
     */
    public static function find($id)
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->execute([$id]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    /**
     * Actualiza la información de un usuario
     */
    public static function update($id, $data)
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->prepare("UPDATE users SET nombre = ?, email = ?, password = ? WHERE id = ?");
        return $stmt->execute([$data['nombre'], $data['email'], $data['password'], $id]);
    }

    /**
     * Elimina un usuario de la base de datos
     */
    public static function delete($id)
    {
        $pdo = Connection::getInstance();
        $stmt = $pdo->prepare("DELETE FROM users WHERE id = ?");
        return $stmt->execute([$id]);
    }
}
